/**
 * Copyright 2012 Bull S.A.S.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */


package org.ow2.util.maven.deploymentplan.filter;

import org.junit.Test;
import org.sonatype.aether.graph.DependencyFilter;

import static java.util.Arrays.asList;
import static org.junit.Assert.assertFalse;
import static org.junit.Assert.assertTrue;
import static org.ow2.util.maven.deploymentplan.util.MavenUtils.node;
import static org.ow2.util.maven.deploymentplan.util.MavenUtils.type;

/**
 * A {@code DirectDependencyFilterTestCase} is ...
 *
 * @author Guillaume Sauthier
 */
public class DirectDependencyFilterTestCase {

    @Test
    public void testThatLevelOneDependenciesAreAccepted() throws Exception {
        DependencyFilter filter = new DirectDependencyFilter();

        assertTrue(filter.accept(node("util:under-test:1.0", type("pom")),
                asList(
                        node("util:used-by:1.0", type("jar"))
                )));
    }

    @Test
    public void testThatLevelOtherThanOneDependenciesAreRejected() throws Exception {
        DependencyFilter filter = new DirectDependencyFilter();

        assertFalse(filter.accept(node("util:under-test:1.0", type("pom")),
                asList(
                        node("util:used-by:1.0", type("jar")),
                        node("util:grand-used-by:1.2", type("plan"))
                )));
    }

}
