/**
 * Copyright 2012 Bull S.A.S.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.maven.deploymentplan.filter;

import java.util.Collections;

import org.junit.Test;
import org.sonatype.aether.graph.DependencyFilter;
import org.sonatype.aether.graph.DependencyNode;

import static org.junit.Assert.assertFalse;
import static org.junit.Assert.assertTrue;
import static org.ow2.util.maven.deploymentplan.util.MavenUtils.node;
import static org.ow2.util.maven.deploymentplan.util.MavenUtils.type;

/**
 * A {@code PlanDependencyFilterTestCase} is ...
 *
 * @author Guillaume Sauthier
 */
public class PlanDependencyFilterTestCase {

    @Test
    public void testThatDeploymentPlanIsAccepted() throws Exception {
        DependencyFilter filter = new PlanDependencyFilter();

        assertTrue(filter.accept(node("util:artifact:1.0", type("deployment-plan")),
                                 Collections.<DependencyNode>emptyList()));
    }

    @Test
    public void testThatNonDeploymentPlanIsRefused() throws Exception {
        DependencyFilter filter = new PlanDependencyFilter();

        assertFalse(filter.accept(node("util:artifact:1.0", type("jar")),
                Collections.<DependencyNode>emptyList()));
        assertFalse(filter.accept(node("util:artifact:1.0", type("bunde")),
                Collections.<DependencyNode>emptyList()));
    }


}
