/**
 * Copyright 2011-2012 Bull S.A.S.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.maven.deploymentplan.mock;

import java.util.Collections;
import java.util.Set;

import org.apache.maven.artifact.Artifact;
import org.apache.maven.artifact.DefaultArtifact;
import org.apache.maven.artifact.handler.DefaultArtifactHandler;
import org.apache.maven.artifact.versioning.VersionRange;
import org.apache.maven.project.MavenProject;

/**
 * A {@code MockProject} is ...
 *
 * @author Guillaume Sauthier
 */
public class MockProject extends MavenProject {
    public MockProject() {
        setGroupId("test");
        setArtifactId("test-plan");
        setPackaging("deployment-plan");
        setVersion("1.0");
    }

    @Override
    public Artifact getArtifact() {
        VersionRange range = VersionRange.createFromVersion("1.0");
        return new DefaultArtifact("test", "test-plan", range, null, "deployment-plan", "C", new PlanArtifactHandler());
    }

    @Override
    public Set<Artifact> getDependencyArtifacts() {
        VersionRange range = VersionRange.createFromVersion("1.0");
        Artifact dep = new DefaultArtifact("G", "A", range, null, "jar", "C", new DefaultArtifactHandler("jar"));
        return Collections.singleton(dep);
    }

    private class PlanArtifactHandler extends DefaultArtifactHandler {
        private PlanArtifactHandler() {
            super("deployment-plan");
            setExtension("xml");
        }
    }
}
