/**
 * Copyright 2012 Bull S.A.S.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */


package org.ow2.util.maven.deploymentplan.util;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.Map;

import org.apache.maven.artifact.handler.DefaultArtifactHandler;
import org.sonatype.aether.artifact.Artifact;
import org.sonatype.aether.graph.Dependency;
import org.sonatype.aether.graph.DependencyNode;
import org.sonatype.aether.util.artifact.ArtifactProperties;
import org.sonatype.aether.util.artifact.DefaultArtifact;
import org.sonatype.aether.util.graph.DefaultDependencyNode;

/**
 * A {@code MavenUtils} is ...
 *
 * @author Guillaume Sauthier
 */
public class MavenUtils {

    public static DefaultArtifactHandler PLAN_HANDLER = new PlanArtifactHandler("deployment-plan");
    public static DefaultArtifactHandler JAR_HANDLER = new DefaultArtifactHandler("jar");


    public static Map<String, String> type(String name) {
        Map<String, String> properties = new HashMap<String, String>();
        properties.put(ArtifactProperties.TYPE, name);
        return properties;
    }

    public static DependencyNode node(String name, Map<String, String> properties) {
        return new DefaultDependencyNode(new Dependency(artifact(name, properties), "compile"));
    }

    public static Artifact artifact(String identifier, Map<String, String> properties) {
        // <groupId>:<artifactId>[:<extension>[:<classifier>]]:<version>
        return new DefaultArtifact(identifier, properties);
    }

    public static Dependency dependency(Artifact artifact) {
        return new Dependency(artifact, "compile");
    }

    public static org.apache.maven.shared.dependency.graph.DependencyNode dependencyNode(org.apache.maven.shared.dependency.graph.DependencyNode parent, org.apache.maven.artifact.Artifact artifact) {
        org.apache.maven.shared.dependency.graph.internal.DefaultDependencyNode node = new org.apache.maven.shared.dependency.graph.internal.DefaultDependencyNode(parent, artifact, null, null, null);
        node.setChildren(new ArrayList<org.apache.maven.shared.dependency.graph.DependencyNode>());
        return node;
    }

    private static class PlanArtifactHandler extends DefaultArtifactHandler {
        public PlanArtifactHandler(String type) {
            super(type);
            setExtension("xml");
        }
    }
}
